summaryrefslogtreecommitdiffstats
path: root/gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h
diff options
context:
space:
mode:
Diffstat (limited to 'gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h')
-rw-r--r--gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h b/gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h
index e9504d70e2ae..8b8760d46abf 100644
--- a/gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h
+++ b/gpu/skia_bindings/gl_bindings_skia_cmd_buffer.h
@@ -9,12 +9,18 @@
struct GrGLInterface;
+namespace gpu {
+namespace gles2 {
+class GLES2Interface;
+} // namespace gles2
+} // namespace gpu
+
namespace skia_bindings {
// The GPU back-end for skia requires pointers to GL functions. This function
-// initializes bindings for skia-gpu to the cmd buffers GL.
-void InitCommandBufferSkiaGLBinding(GrGLInterface*);
+// initializes bindings for skia-gpu to a GLES2Interface object.
+void InitGLES2InterfaceBindings(GrGLInterface*, gpu::gles2::GLES2Interface*);
-} // namespace skia
+} // namespace skia_bindings
#endif // GPU_SKIA_BINDINGS_GL_BINDINGS_SKIA_CMD_BUFFER_H_